---
name: standard issue template
about: Create a report to help us improve
title: ''
labels: ''
assignees: ''
---

### Description
<!-- Describe what you were trying to get done. Tell us what happened, what went wrong, and what you expected to happen. -->

## Steps to Reproduce
<!--- Provide a link to a live example, or an unambiguous set of steps to -->
<!--- reproduce this bug. Include code to reproduce, if relevant -->
1.
2.
3.
4.

## Context (Environment)
### `datacube-ows` version (datacube-ows-update --version):
<!-- Run command datacube-ows-update --version -->

### `ows_config.py` file (link, sample code)
<!-- Provide a link to config or paste the config code below -->

### datacube product metadata (datacube product show product_name)
<!-- If issue is related to a specific layer, run `datacube product show <product_name>` to get the product metadata and provide below -->
